@@ -1,19 +1,19 @@
 
-#' Download Latest Station List Information and Update GSODR's Internal Database
+#' Download Latest Station List Information and Update Internal Database
 #'
 #' This function downloads the latest station list (isd-history.csv) from the
-#' NCEI FTP server and updates the data distributed with \pkg{GSODR} to the
-#' latest stations available.  These data provide unique identifiers, country,
-#' state (if in US), latitude, longitude, elevation and when weather
-#' observations begin and end.  Stations with invalid latitude and longitude
-#' values will not be included.
+#' \acronym{NCEI} \acronym{FTP} server and updates the data distributed with
+#' \pkg{GSODR} to the latest stations available.  These data provide unique
+#' identifiers, country, state (if in U.S.), latitude, longitude, elevation and
+#' when weather observations begin and end.  Stations with invalid latitude and
+#' longitude values will not be included.
 #'
 #' Care should be taken when using this function if reproducibility is necessary
 #' as different machines with the same version of \pkg{GSODR} can end up with
 #' different versions of the isd_history.csv file internally.
 #'
 #' There is no need to use this unless you know that a station exists in the
-#' GSODR data that is not available in the self-contained database.
+#' \pkg{GSODR} data that is not available in the self-contained database.
 #'
 #' To directly access these data, use: \cr
 #' \code{load(system.file("extdata", "isd_history.rda", package = "GSODR"))}
@@ -24,9 +24,24 @@
 #' }
 #'
 #' @author Adam H Sparks, \email{adamhsparks@@gmail.com}
-#' @export
-#'
+#' @export update_station_list
+
 update_station_list <- function() {
+  message(
+    "This will overwrite GSODR's current internal list of GSOD stations.\n",
+    "If reproducibility is necessary, you may not wish to proceed.\n",
+    "Do you understand and wish to proceed (Y/n)?\n")
+
+  answer <-
+    readLines(con = getOption("GSODR_connection"), n = 1)
+
+  answer <- toupper(answer)
+
+  if (answer != "Y" & answer != "YES") {
+    stop("Station list was not updated.",
+         call. = FALSE)
+  }
+
   original_timeout <- options("timeout")[[1]]
   options(timeout = 300)
   on.exit(options(timeout = original_timeout))
